@@ -14,14 +14,19 @@ from zope.interface import implementer
 class ISectionContact(ISection):
     """Marker interface and Dexterity Python Schema for SectionContact"""
 
-    directives.widget(related_contact=SelectFieldWidget)
-    related_contact = schema.Choice(
-        title=_("Related contact"),
+    directives.widget(
+        "related_contacts",
+        SelectFieldWidget,
+        vocabulary="imio.smartweb.vocabulary.RemoteContacts",
+        pattern_options={"multiple": True},
+    )
+    related_contacts = schema.List(
+        title=_("Related contacts"),
         description=_(
-            "Select a contact. If you can't find the contact you want, make sure "
+            "Select contacts. If you can't find contacts you want, make sure "
             """it exists in the directory and that its "state" is published."""
         ),
-        source="imio.smartweb.vocabulary.RemoteContacts",
+        value_type=schema.Choice(source="imio.smartweb.vocabulary.RemoteContacts"),
         required=True,
     )
 
@@ -36,17 +41,12 @@ class ISectionContact(ISection):
     model.fieldset(
         "layout",
         fields=[
-            "is_in_portrait_mode",
             "gallery_mode",
             "nb_results_by_batch",
             "image_scale",
         ],
     )
 
-    is_in_portrait_mode = schema.Bool(
-        title=_("Switch lead image to portrait mode"), required=False, default=False
-    )
-
     gallery_mode = schema.Choice(
         title=_("Gallery mode"),
         description=_("Choose your gallery layout mode"),
@@ -58,13 +58,21 @@ class ISectionContact(ISection):
         title=_("Number of items per batch (only for carousel mode)"),
         required=True,
         default=3,
-        values=[1, 3, 4],
+        values=[1, 2, 3, 4],
+    )
+
+    nb_contact_by_line = schema.Choice(
+        title=_("Maximum number of contacts by line"),
+        description=_("Maximum number of contacts by line (on PC)"),
+        required=True,
+        default=4,
+        values=[1, 2, 3, 4],
     )
 
     image_scale = schema.Choice(
         title=_("Image scale for images (only for gallery mode)"),
-        default="preview",
-        vocabulary="plone.app.vocabularies.ImagesScales",
+        default="affiche",
+        vocabulary="imio.smartweb.vocabulary.Scales",
         required=True,
     )
 
