@@ -4,4 +4,4 @@ from plone.app.layout.viewlets.social import SocialTagsViewlet as BaseSocialTags
 
 
 class SocialTagsViewlet(BaseSocialTagsViewlet):
-    social_image_scale = "vignette"
+    social_image_scale = "paysage_vignette"
