@@ -135,6 +135,23 @@ class BootstrapCSSVocabularyFactory:
 BootstrapCSSVocabulary = BootstrapCSSVocabularyFactory()
 
 
+class OrientationVocabularyFactory:
+    def __call__(self, context=None):
+        values = [
+            ("paysage", _("Paysage")),
+            ("portrait", _("Portrait")),
+            ("carre", _("Carre")),
+        ]
+        terms = [
+            SimpleVocabulary.createTerm(value[0], value[0], value[1])
+            for value in values
+        ]
+        return SimpleVocabulary(terms)
+
+
+OrientationVocabulary = OrientationVocabularyFactory()
+
+
 class SubsiteDisplayModeVocabularyFactory:
     def __call__(self, context=None):
         display_mode = [
@@ -185,7 +202,7 @@ class RemoteContactsVocabularyFactory:
             "metadata_fields=breadcrumb",
         ]
         url = "{}/@search?{}".format(DIRECTORY_URL, "&".join(params))
-        json_contacts = get_json(url)
+        json_contacts = get_json(url, None, 8)
         if json_contacts is None or len(json_contacts.get("items", [])) == 0:
             return SimpleVocabulary([])
         return SimpleVocabulary(
@@ -305,10 +322,11 @@ AlignmentVocabulary = AlignmentVocabularyFactory()
 class ImageSizeVocabularyFactory:
     def __call__(self, context=None):
         image_size = [
-            ("extralarge", _("Full width")),
-            ("large", _("Half page")),
-            ("medium", _("Third page")),
+            ("affiche", _("Full width")),
+            # ("affiche", _("Half page")),  # unique values only (see WEB-3934)
+            ("vignette", _("Third page")),
         ]
+        _("Half page")  # don't throw away term translation
         terms = [SimpleTerm(value=t[0], token=t[0], title=t[1]) for t in image_size]
         return SimpleVocabulary(terms)
 
